package flink.zanxiangnet.ad.monitoring.process;

import flink.zanxiangnet.ad.monitoring.pojo.entity.AdStatOfHourDWD;
import flink.zanxiangnet.ad.monitoring.util.DateUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.flink.api.common.state.ValueState;
import org.apache.flink.api.common.state.ValueStateDescriptor;
import org.apache.flink.api.common.typeinfo.Types;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.streaming.api.functions.KeyedProcessFunction;
import org.apache.flink.util.Collector;

import java.time.LocalDateTime;
import java.time.LocalTime;

/**
 * 小时流数据补全，把中间没消耗的时间段填充 0
 */
@Slf4j
public class AdHourRollbackStreamCompletionProcess extends KeyedProcessFunction<Long, AdStatOfHourDWD, AdStatOfHourDWD> {

    private ValueState<AdStatOfHourDWD> lastReduceState;

    @Override
    public void open(Configuration conf) {
        lastReduceState = getRuntimeContext().getState(new ValueStateDescriptor<>("lastReduceState", Types.POJO(AdStatOfHourDWD.class)));
    }

    @Override
    public void processElement(AdStatOfHourDWD adStatOfHourDWD, KeyedProcessFunction<Long, AdStatOfHourDWD, AdStatOfHourDWD>.Context context, Collector<AdStatOfHourDWD> collector) throws Exception {
        AdStatOfHourDWD lastReduce = lastReduceState.value();
        if (lastReduce == null) {
            lastReduceState.update(adStatOfHourDWD);
            collector.collect(adStatOfHourDWD);
            return;
        }
        LocalDateTime statDateTime = LocalDateTime.of(DateUtil.parseLocalDate(adStatOfHourDWD.getStatDay()), LocalTime.of(adStatOfHourDWD.getHour(), 0, 0));
        LocalDateTime lastStatDateTime = LocalDateTime.of(DateUtil.parseLocalDate(lastReduce.getStatDay()), LocalTime.of(lastReduce.getHour(), 0, 0));
        if (lastStatDateTime.compareTo(statDateTime) >= 0) {
            lastReduceState.update(adStatOfHourDWD);
            collector.collect(adStatOfHourDWD);
            return;
        }
        long hours = DateUtil.intervalOfHour(lastStatDateTime, statDateTime);
        if (hours > 1) {
            if (hours > 24) {
                log.error("回滚：adId[{}] 要造 {}条数据, 从 {} 到 {}结束", adStatOfHourDWD.getAdId(), hours, lastStatDateTime, statDateTime);
            }
            long start = System.currentTimeMillis();
            // 中间有没数据的时间段，需要进行数据填充
            for (int i = 1; i < (hours >= 24 ? 24 : hours); i++) {
                // 要填充的时间
                LocalDateTime completionTime = lastStatDateTime.plusHours(i);
                collector.collect(AdStatOfHourDWD.completion(completionTime, lastReduce));
            }
            if (hours > 24) {
                log.error("回滚：给 adId[{}]造数据用时 {}", adStatOfHourDWD.getAdId(), (System.currentTimeMillis() - start));
            }
        }
        collector.collect(adStatOfHourDWD);
        lastReduceState.update(adStatOfHourDWD);
    }
}
