package flink.zanxiangnet.ad.monitoring.process;

import flink.zanxiangnet.ad.monitoring.pojo.entity.AdStatOfHourDWD;
import flink.zanxiangnet.ad.monitoring.pojo.entity.CostHourDM;
import flink.zanxiangnet.ad.monitoring.util.DateUtil;
import org.apache.flink.api.common.state.MapState;
import org.apache.flink.api.common.state.MapStateDescriptor;
import org.apache.flink.api.common.typeinfo.Types;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.streaming.api.functions.KeyedProcessFunction;
import org.apache.flink.util.Collector;

import java.io.IOException;
import java.sql.SQLException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.util.*;

public class CostHourProcess extends KeyedProcessFunction<Long, AdStatOfHourDWD, CostHourDM> {

    private MapState<String, Map<Integer, AdStatOfHourDWD>> historyReduceState;


    @Override
    public void open(Configuration conf) throws SQLException, ClassNotFoundException, IOException {
        historyReduceState = getRuntimeContext().getMapState(new MapStateDescriptor<>("historyReduceState", Types.STRING, Types.MAP(Types.INT, Types.POJO(AdStatOfHourDWD.class))));
    }

    //数据格式转换
    public CostHourDM dataChange(AdStatOfHourDWD adStatOfMinuteDWD) {
        CostHourDM costHourDM = new CostHourDM();
        //时间-天
        costHourDM.dt = adStatOfMinuteDWD.getStatDay();
        //计划 id
        costHourDM.campaignId = adStatOfMinuteDWD.getCampaignId().toString();
        //时间- real
        costHourDM.createTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(adStatOfMinuteDWD.getCreateTime());
        //时间-小时
        //TODO:之后需要进一步修改
        String tmpHour = adStatOfMinuteDWD.getHour() > 9 ? adStatOfMinuteDWD.getHour().toString() : "0" + adStatOfMinuteDWD.getHour().toString();
        costHourDM.hour = adStatOfMinuteDWD.getStatDay() + " " + tmpHour + ":00:00";
        //广告id
        costHourDM.adId = adStatOfMinuteDWD.getAdId().toString();
        //服务商id
        costHourDM.agencyAccountId = adStatOfMinuteDWD.getAgencyAccountId().toString();
        //广告组id
        costHourDM.adgroupId = adStatOfMinuteDWD.getAdgroupId().toString();
        //创意id
        costHourDM.adcreativeId = "";
        //账号id
        costHourDM.accountId = adStatOfMinuteDWD.getAccountId().toString();
        //总消耗
        costHourDM.costTotal = adStatOfMinuteDWD.getCostTotal();
        //当天消耗
        costHourDM.costDay = adStatOfMinuteDWD.getCostDay();
        //当天小时消耗
        costHourDM.costHour = adStatOfMinuteDWD.getCostHour();
        //消耗速度
        costHourDM.costSpeed = adStatOfMinuteDWD.getCostHour();
        //总浏览量
        costHourDM.viewCountTotal = adStatOfMinuteDWD.getViewCountTotal();
        //天-总浏览量
        costHourDM.viewCountDay = adStatOfMinuteDWD.getViewCountDay();
        //小时-总浏览量
        costHourDM.viewCountHour = adStatOfMinuteDWD.getViewCountHour();
        //总平均千次曝光成本
        costHourDM.thousandDisplayPriceAll = adStatOfMinuteDWD.getThousandDisplayPriceAll();
        //天-总平均曝光成本
        costHourDM.thousandDisplayPriceDay = adStatOfMinuteDWD.getThousandDisplayPriceDay();
        //小时-总平均曝光成本
        costHourDM.thousandDisplayPriceHour = adStatOfMinuteDWD.getThousandDisplayPriceHour();
        //总点击量
        costHourDM.validClickCountTotal = adStatOfMinuteDWD.getValidClickCountTotal();
        //天-总点击量
        costHourDM.validClickCountDay = adStatOfMinuteDWD.getValidClickCountDay();
        //小时-总点击量
        costHourDM.validClickCountHour = adStatOfMinuteDWD.getValidClickCountHour();
        //总平均点击率
        costHourDM.ctrAll = adStatOfMinuteDWD.getCtrAll();
        //天-总平均点击率
        costHourDM.ctrDay = adStatOfMinuteDWD.getCtrDay();
        //小时-总平均点击率
        costHourDM.ctrHour = adStatOfMinuteDWD.getCtrHour();
        //总点击均价
        costHourDM.cpcAll = adStatOfMinuteDWD.getCpcAll();
        //天-总点击均价
        costHourDM.cpcDay = adStatOfMinuteDWD.getCpcDay();
        //小时-总点击均价
        costHourDM.cpcHour = adStatOfMinuteDWD.getCpcHour();
        //总目标转化量
        costHourDM.conversionsCountTotal = adStatOfMinuteDWD.getConversionsCountTotal();
        //天-总目标转化量
        costHourDM.conversionsCountDay = adStatOfMinuteDWD.getConversionsCountDay();
        //小时-总目标转化量
        costHourDM.conversionsCountHour = adStatOfMinuteDWD.getConversionsCountHour();
        //总目标平均转化成本
        costHourDM.conversionsCostTotal = adStatOfMinuteDWD.getConversionsCostAll();
        //天-总目标平均转化成本
        costHourDM.conversionsCostDay = adStatOfMinuteDWD.getConversionsCostDay();
        //小时-总目标平均转化成本
        costHourDM.conversionsCostHour = adStatOfMinuteDWD.getConversionsCostHour();
        //总平均转化率
        costHourDM.conversionsRateAll = adStatOfMinuteDWD.getConversionsRateAll();
        //天-总平均转化率
        costHourDM.conversionsRateDay = adStatOfMinuteDWD.getConversionsRateDay();
        //小时-总平均转化率
        costHourDM.conversionsRateHour = adStatOfMinuteDWD.getConversionsRateHour();
        //TODO:总首日下单roi
        costHourDM.firstDayOrderRoiTotal = 0;
        //天-总首日下单roi
        costHourDM.firstDayOrderRoiDay = 0;
        //小时-总首日下单roi
        costHourDM.firstDayOrderRoiHour = 0;
        //总首日下单金额
        costHourDM.firstDayOrderAmountTotal = adStatOfMinuteDWD.getFirstDayOrderAmountTotal();
        //天-总首日下单金额
        costHourDM.firstDayOrderAmountDay = adStatOfMinuteDWD.getFirstDayOrderAmountDay();
        //小时-总首日下单金额
        costHourDM.firstDayOrderAmountHour = adStatOfMinuteDWD.getFirstDayOrderAmountHour();
        //总首日下单量
        costHourDM.firstDayOrderCountTotal = adStatOfMinuteDWD.getFirstDayOrderCountTotal();
        //天-总首日下单量
        costHourDM.firstDayOrderCountDay = adStatOfMinuteDWD.getFirstDayOrderCountDay();
        //小时-总首日下单量
        costHourDM.firstDayOrderCountHour = adStatOfMinuteDWD.getFirstDayOrderCountHour();
        //总下单金额
        costHourDM.webOrderAmountTotal = adStatOfMinuteDWD.getOrderAmountTotal();
        //天-总下单金额
        costHourDM.webOrderAmountDay = adStatOfMinuteDWD.getOrderAmountDay();
        //小时-总下单金额
        costHourDM.webOrderAmountHour = adStatOfMinuteDWD.getOrderAmountHour();
        //总平均下单成本
        costHourDM.webOrderCostTotal = adStatOfMinuteDWD.getWebOrderCostAll();
        //天-总平均下单成本
        costHourDM.webOrderCostDay = adStatOfMinuteDWD.getWebOrderCostDay();
        //小时-总平均下单成本
        costHourDM.webOrderCostHour = adStatOfMinuteDWD.getWebOrderCostHour();
        //总平均下单率
        costHourDM.webOrderRateTotal = adStatOfMinuteDWD.getOrderRateAll();
        //天-总平均下单率
        costHourDM.webOrderRateDay = adStatOfMinuteDWD.getOrderRateDay();
        //小时-总平均下单率
        costHourDM.webOrderRateHour = adStatOfMinuteDWD.getOrderRateHour();
        //TODO:总平均下单量-----webordercount和ordercount是同一个东西吗
        costHourDM.webOrderCountTotal = adStatOfMinuteDWD.getOrderCountTotal();
        //天-总平均下单量
        costHourDM.webOrderCountDay = adStatOfMinuteDWD.getOrderCountDay();
        //小时-总平均下单量
        costHourDM.webOrderCountHour = adStatOfMinuteDWD.getOrderCountHour();
        //总下单ROI
        costHourDM.orderRoiTotal = adStatOfMinuteDWD.getOrderRoiAll();
        //天-总下单roi
        costHourDM.orderRoiDay = adStatOfMinuteDWD.getOrderRoiDay();
        //小时-总下单roi
        costHourDM.orderRoiHour = adStatOfMinuteDWD.getOrderRoiHour();
        //总平均下单客单价
        costHourDM.orderUnitPriceTotal = adStatOfMinuteDWD.getOrderUnitPriceAll();
        //天-总平均下单客单价
        costHourDM.orderUnitPriceDay = adStatOfMinuteDWD.getOrderUnitPriceDay();
        //小时-总平均下单客单价
        costHourDM.orderUnitPriceHour = adStatOfMinuteDWD.getOrderUnitPriceHour();
        //总公众号关注量
        costHourDM.fromFollowUvTotal = adStatOfMinuteDWD.getOfficialAccountFollowCountTotal();
        //天-总公众号关注量
        costHourDM.fromFollowUvDay = adStatOfMinuteDWD.getOfficialAccountFollowCountDay();
        //小时-总公众号关注量
        costHourDM.fromFollowUvHour = adStatOfMinuteDWD.getOfficialAccountFollowCountHour();
        //TODO:总平均公众号关注成本---是否是价格/关注
        costHourDM.fromFollowCostTotal = adStatOfMinuteDWD.getOfficialAccountFollowCountTotal() == 0 ? 0 : adStatOfMinuteDWD.getCostTotal() / adStatOfMinuteDWD.getOfficialAccountFollowCountTotal();
        //天-总平均公众号关注成本
        costHourDM.fromFollowCostDay = adStatOfMinuteDWD.getOfficialAccountFollowCountDay() == 0 ? 0 : adStatOfMinuteDWD.getCostDay() / adStatOfMinuteDWD.getOfficialAccountFollowCountDay();
        //小时-总平均公众号关注成本
        costHourDM.fromFollowCostHour = adStatOfMinuteDWD.getOfficialAccountFollowCountHour() == 0 ? 0 : adStatOfMinuteDWD.getCostHour() / adStatOfMinuteDWD.getOfficialAccountFollowCountHour();
        //TODO:总平均公众号关注率----确认是否对应
        costHourDM.fromFollowRateTotal = adStatOfMinuteDWD.getOfficialAccountFollowRateAll();
        //天-总平均公众号关注率
        costHourDM.fromFollowRateDay = adStatOfMinuteDWD.getOfficialAccountFollowRateDay();
        //小时-总平均公众号关注率
        costHourDM.fromFollowRateHour = adStatOfMinuteDWD.getOfficialAccountFollowRateHour();
        //TODO:总注册数-----下面全是有问题的
        costHourDM.webRegisterCountTotal = adStatOfMinuteDWD.getOfficialAccountRegisterUserCountTotal();
        //天-总注册数
        costHourDM.webRegisterCountDay = adStatOfMinuteDWD.getOfficialAccountRegisterUserCountDay();
        //小时-总注册数
        costHourDM.webRegisterCountHour = adStatOfMinuteDWD.getOfficialAccountRegisterUserCountHour();
        //总注册人数
        costHourDM.webRegisterUvTotal = adStatOfMinuteDWD.getOfficialAccountRegisterUserCountTotal();
        //天-总注册人数
        costHourDM.webRegisterUvDay = adStatOfMinuteDWD.getOfficialAccountRegisterUserCountDay();
        //小时-总注册人数
        costHourDM.webRegisterUvHour = adStatOfMinuteDWD.getOfficialAccountRegisterUserCountHour();
        //总平均注册成本
        costHourDM.webRegisterCostTotal = adStatOfMinuteDWD.getOfficialAccountRegisterCostAll();
        //天-总平均注册成本
        costHourDM.webRegisterCostDay = adStatOfMinuteDWD.getOfficialAccountRegisterCostDay();
        //小时-总平均注册成本
        costHourDM.webRegisterCostHour = adStatOfMinuteDWD.getOfficialAccountRegisterCostHour();
        return costHourDM;
    }

    @Override
    public void processElement(AdStatOfHourDWD adStatOfHourDWD, KeyedProcessFunction<Long, AdStatOfHourDWD, CostHourDM>.Context context,
                               Collector<CostHourDM> collector) throws Exception {
        LocalDate day = DateUtil.parseLocalDate(adStatOfHourDWD.getStatDay());
        Integer hour = adStatOfHourDWD.getHour();

        LocalDate lastHourDay = day, lastTwoHourDay = day, lastThreeHourDay = day;
        int lastHour = hour - 1, lastTwoHour = hour - 2, lastThreeHour = hour - 3;
        if (hour == 0) {
            lastHourDay = day.minusDays(1L);
            lastHour = 23;
            lastTwoHourDay = day.minusDays(1L);
            lastTwoHour = 22;
            lastThreeHourDay = day.minusDays(1L);
            lastThreeHour = 21;
        } else if (hour == 1) {
            lastTwoHourDay = day.minusDays(1L);
            lastTwoHour = 23;
            lastThreeHourDay = day.minusDays(1L);
            lastThreeHour = 22;
        } else if (hour == 2) {
            lastThreeHourDay = day.minusDays(1L);
            lastThreeHour = 23;
        }
        long costDiff = 0L, costLastHour = 0L;
        Map<Integer, AdStatOfHourDWD> lastHourMapping = historyReduceState.get(DateUtil.formatLocalDate(lastHourDay));
        if (lastHourMapping != null && !lastHourMapping.isEmpty()) {
            AdStatOfHourDWD lastHourDWD = lastHourMapping.get(lastHour);
            if (lastHourDWD != null) {
                costLastHour = lastHourDWD.getCostHour();
                costDiff = adStatOfHourDWD.getCostHour() - lastHourDWD.getCostHour();
            }
        }
        long costLastHourDiff = 0, costLastTwoHour = 0;
        Map<Integer, AdStatOfHourDWD> lastTwoHourMapping = historyReduceState.get(DateUtil.formatLocalDate(lastTwoHourDay));
        if (lastTwoHourMapping != null && !lastTwoHourMapping.isEmpty()) {
            AdStatOfHourDWD lastTwoHourDWD = lastTwoHourMapping.get(lastTwoHour);
            if (lastTwoHourDWD != null) {
                costLastTwoHour = lastTwoHourDWD.getCostHour();
                costLastHourDiff = costLastHour - lastTwoHourDWD.getCostHour();
            }
        }
        long costLastTwoHourDiff = 0, costLastThreeTrend = 0;
        Map<Integer, AdStatOfHourDWD> lastThreeHourMapping = historyReduceState.get(DateUtil.formatLocalDate(lastThreeHourDay));
        if (lastThreeHourMapping != null && !lastThreeHourMapping.isEmpty()) {
            AdStatOfHourDWD lastThreeHourDWD = lastThreeHourMapping.get(lastThreeHour);
            if (lastThreeHourDWD != null) {
                costLastThreeTrend = costLastHourDiff > 0 && costDiff > 0 ? 1 : 0;
                costLastTwoHourDiff = costLastTwoHour - lastThreeHourDWD.getCostHour();
            }
        }

        if (historyReduceState.get(adStatOfHourDWD.getStatDay()) == null) {
            Map<Integer, AdStatOfHourDWD> hourMapping = new HashMap<>(24);
            hourMapping.put(adStatOfHourDWD.getHour(), adStatOfHourDWD);
            historyReduceState.put(adStatOfHourDWD.getStatDay(), hourMapping);
        } else {
            historyReduceState.get(adStatOfHourDWD.getStatDay()).put(adStatOfHourDWD.getHour(), adStatOfHourDWD);
        }

        CostHourDM costHourDM = dataChange(adStatOfHourDWD);
        costHourDM.setCostDiff(costDiff);
        costHourDM.setCostLastHour(costLastHour);
        costHourDM.setCostLastHourDiff(costLastHourDiff);
        costHourDM.setCostLastTwoHour(costLastTwoHour);
        costHourDM.setCostLastTwoHourDiff(costLastTwoHourDiff);
        costHourDM.setCostLastThreeTrend(costLastThreeTrend);

        collector.collect(costHourDM);
        historyReduceState.remove(DateUtil.formatLocalDate(day.minusDays(2L)));
        historyReduceState.remove(DateUtil.formatLocalDate(day.minusDays(3L)));

    }
}
